HashSetExt

Trait HashSetExt 

pub trait HashSetExt {
    // Required methods
    fn new() -> Self;
    fn with_capacity(capacity: usize) -> Self;
}
A convenience trait that can be used together with the type aliases defined to get access to the new() and with_capacity() methods for the HashSet type aliases.

Required Methods

fn new() -> Self

Constructs a new HashSet

fn with_capacity(capacity: usize) -> Self

Constructs a new HashSet with a given initial capacity

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<K, S> HashSetExt for HashSet<K, S>
where S: BuildHasher + Default,

Available on crate feature std only.
Source

fn new() -> Self

Source

fn with_capacity(capacity: usize) -> Self

Implementors