pub struct AHasher { /* private fields */ }Expand description
A Hasher for hashing an arbitrary stream of bytes.
Instances of AHasher represent state that is updated while hashing data.
Each method updates the internal state based on the new data provided. Once
all of the data has been provided, the resulting hash can be obtained by calling
finish()
Clone is also provided in case you wish to calculate hashes for two different items that start with the same data.
Implementations
sourceimpl AHasher
impl AHasher
sourcepub fn new_with_keys(key1: u128, key2: u128) -> Self
pub fn new_with_keys(key1: u128, key2: u128) -> Self
Creates a new hasher keyed to the provided keys.
Normally hashers are created via AHasher::default() for fixed keys or RandomState::new() for randomly
generated keys and RandomState::with_seeds(a,b) for seeds that are set and can be reused. All of these work at
map creation time (and hence don’t have any overhead on a per-item bais).
This method directly creates the hasher instance and performs no transformation on the provided seeds. This may be useful where a HashBuilder is not desired, such as for testing purposes.
Example
use std::hash::Hasher;
use ahash::AHasher;
let mut hasher = AHasher::new_with_keys(1234, 5678);
hasher.write_u32(1989);
hasher.write_u8(11);
hasher.write_u8(9);
hasher.write(b"Huh?");
println!("Hash is {:x}!", hasher.finish());Trait Implementations
sourceimpl Default for AHasher
impl Default for AHasher
Provides a default Hasher with fixed keys. This is typically used in conjunction with BuildHasherDefault to create AHashers in order to hash the keys of the map.
Generally it is preferable to use RandomState instead, so that different hashmaps will have different keys. However if fixed keys are desireable this may be used instead.
Example
use std::hash::BuildHasherDefault;
use ahash::{AHasher, RandomState};
use std::collections::HashMap;
let mut map: HashMap<i32, i32, BuildHasherDefault<AHasher>> = HashMap::default();
map.insert(12, 34);sourcefn default() -> AHasher
fn default() -> AHasher
Constructs a new AHasher with fixed keys.
If std is enabled these will be generated upon first invocation.
Otherwise if the compile-time-rngfeature is enabled these will be generated at compile time.
If neither of these features are available, hardcoded constants will be used.
Because the values are fixed, different hashers will all hash elements the same way. This could make hash values predictable, if DOS attacks are a concern. If this behaviour is not required, it may be preferable to use RandomState instead.
Examples
use ahash::AHasher;
use std::hash::Hasher;
let mut hasher_1 = AHasher::default();
let mut hasher_2 = AHasher::default();
hasher_1.write_u32(1234);
hasher_2.write_u32(1234);
assert_eq!(hasher_1.finish(), hasher_2.finish());sourceimpl Hasher for AHasher
impl Hasher for AHasher
Provides Hasher methods to hash all of the primitive types.
sourcefn write_u128(&mut self, i: u128)
fn write_u128(&mut self, i: u128)
u128 into this hasher.sourcefn write_usize(&mut self, i: usize)
fn write_usize(&mut self, i: usize)
usize into this hasher.1.26.0 · sourcefn write_i128(&mut self, i: i128)
fn write_i128(&mut self, i: i128)
i128 into this hasher.1.3.0 · sourcefn write_isize(&mut self, i: isize)
fn write_isize(&mut self, i: isize)
isize into this hasher.sourcefn write_length_prefix(&mut self, len: usize)
fn write_length_prefix(&mut self, len: usize)
hasher_prefixfree_extras)